@@ -1,8 +1,8 @@
 /*
  *      document.h - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2005-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
- *      Copyright 2006-2009 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
+ *      Copyright 2005-2010 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *      Copyright 2006-2010 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: document.h 4063 2009-08-09 20:31:03Z eht16 $
+ *  $Id: document.h 4928 2010-05-16 17:45:39Z eht16 $
  */
 
 /**
@@ -51,6 +51,7 @@ typedef struct GeanyFilePrefs
 	gboolean		strip_trailing_spaces;
 	gboolean		replace_tabs;
 	gboolean		tab_order_ltr;
+	gboolean		tab_order_beside;
 	gboolean		show_tab_cross;
 	guint			mru_length;
 	gint			default_eol_character;
@@ -109,15 +110,23 @@ struct GeanyDocument
 extern GPtrArray *documents_array;
 
 
-/** Wrap documents_array so it can be used with C array syntax.
+/** Wraps documents_array so it can be used with C array syntax.
  * Example: documents[0]->sci = NULL;
  * @see document_index(). */
 #define documents ((GeanyDocument **)GEANY(documents_array)->pdata)
 
+/** @deprecated Use @ref foreach_document() instead.
+ * Iterates all valid documents.
+ * Use like a @c for statement.
+ * @param i @c guint index for document_index(). */
+#ifndef GEANY_DISABLE_DEPRECATED
+#define documents_foreach(i) foreach_document(i)
+#endif
+
 /** Iterates all valid documents.
  * Use like a @c for statement.
  * @param i @c guint index for document_index(). */
-#define documents_foreach(i) \
+#define foreach_document(i) \
 	for (i = 0; i < GEANY(documents_array)->len; i++)\
 		if (!documents[i]->is_valid)\
 			{}\
@@ -132,8 +141,8 @@ extern GPtrArray *documents_array;
 	(G_LIKELY((doc_ptr) != NULL) && G_LIKELY((doc_ptr)->is_valid))
 
 /**
- *  DOC_FILENAME returns the filename of the document passed or
- *  GEANY_STRING_UNTITLED (e.g. _("untitled")) if the document's filename was not yet set.
+ *  Returns the filename of the document passed or @c GEANY_STRING_UNTITLED
+ *  (e.g. _("untitled")) if the document's filename was not yet set.
  *  This macro never returns @c NULL.
  **/
 #define DOC_FILENAME(doc) \
@@ -184,6 +193,8 @@ void document_finalize(void);
 
 gboolean document_remove_page(guint page_num);
 
+void document_try_focus(GeanyDocument *doc, GtkWidget *source_widget);
+
 gboolean document_close(GeanyDocument *doc);
 
 gboolean document_account_for_unsaved(void);
@@ -208,7 +219,7 @@ gint document_find_text(GeanyDocument *doc, const gchar *text, gint flags, gbool
 gint document_replace_text(GeanyDocument *doc, const gchar *find_text, const gchar *replace_text,
 		gint flags, gboolean search_backwards);
 
-gboolean document_replace_all(GeanyDocument *doc, const gchar *find_text, const gchar *replace_text,
+gint document_replace_all(GeanyDocument *doc, const gchar *find_text, const gchar *replace_text,
 		gint flags, gboolean escaped_chars);
 
 void document_replace_sel(GeanyDocument *doc, const gchar *find_text, const gchar *replace_text, gint flags,
@@ -240,4 +251,8 @@ const GdkColor *document_get_status_color(GeanyDocument *doc);
 
 gchar *document_get_basename_for_display(GeanyDocument *doc, gint length);
 
+gboolean document_need_save_as(GeanyDocument *doc);
+
+void document_apply_indent_settings(GeanyDocument *doc);
+
 #endif
