@@ -23,9 +23,6 @@ commentlinedoc=commentdoc,bold
 commentdockeyword=commentdoc,bold,italic
 commentdockeyworderror=commentdoc
 globalclass=type
-# whether arguments of preprocessor commands should be styled (only first argument is used)
-# 1 to enable, 0 to disable
-styling_within_preprocessor=1;0;false;false
 
 [keywords]
 # all items must be in one line
@@ -34,7 +31,16 @@ secondary=
 # these are some doxygen keywords (incomplete)
 docComment=attention author brief bug class code date def enum example exception file fn namespace note param remarks return see since struct throw todo typedef var version warning union
 
+[lexer_properties]
+styling.within.preprocessor=1
+preprocessor.symbol.$(file.patterns.cpp)=#
+preprocessor.start.$(file.patterns.cpp)=if ifdef ifndef
+preprocessor.middle.$(file.patterns.cpp)=else elif
+preprocessor.end.$(file.patterns.cpp)=endif
+
 [settings]
+lexer_filetype=C
+
 # default extension used when saving files
 #extension=cpp
 
